Shared allocation-free wire framing for Brynja protocol engines.
The crate parses and writes record envelopes only. It does not negotiate a protocol version, decrypt records, maintain replay state, or implement a handshake. Callers must supply an already selected typed protocol profile.
Re-exports
pub use tls::ContentType;pub use tls::ContentTypeClass;pub use tls::ContentTypeCode;pub use tls::Dtls12Ciphertext;pub use tls::Dtls13Ciphertext;pub use tls::Dtls13CiphertextConfig;pub use tls::Dtls13CiphertextHeader;pub use tls::Dtls13Sequence;pub use tls::DtlsPlaintext;pub use tls::HEARTBEAT_EXTENSION_TYPE;pub use tls::LegacyRecordVersion;pub use tls::RecordError;pub use tls::TlsCiphertext;pub use tls::TlsPlaintext;pub use tls::WirePolicy;pub use tls::encode_dtls13_ciphertext;
Modules
- tls
- Version-neutral TLS and DTLS record envelopes.
Constants
- TLS_
DTLS_ RECORD_ FRAMING_ IMPLEMENTED - Whether the bounded TLS and DTLS framing boundary is implemented.